@@ -6,8 +6,11 @@
  *      klin, Tue Jul  7 13:59:47 1992
  *      klin, Sat Aug 15 10:31:50 1992, patchlevel 4
  *                                      Changed <At/..> to <X11/At/..>.
+ *      klin, Fri Dec 11 15:55:12 1992, patchlevel 5
+ *                                      Removed XtPointer macro.
+ *                                      Include patchlevel.h for version defs.
  *
- *      SCCSid[] = "@(#) Plotter V6.0  92/08/15  At.h"
+ *      SCCSid[] = "@(#) Plotter V6.0  92/12/11  At.h"
  */
 
 /*
@@ -64,9 +67,7 @@ SOFTWARE.
 #include <X11/StringDefs.h>
 #include <X11/IntrinsicP.h>
 
-#ifndef XtPointer
-# define XtPointer caddr_t
-#endif
+#include <X11/At/patchlevel.h>
 
 #ifndef P
 # ifdef __STDC__
