@@ -16,8 +16,10 @@
  *      klin, Fri Aug 14 15:45:52 1992, patchlevel 4
  *                                      Minor changes in PS output.
  *                                      Changed <At/..> to <X11/At/..>.
+ *      klin, Fri Feb 12 08:56:57 1993, patchlevel 7
+ *                                      Bug in setting double resources fixed
  */
-static char SCCSid[] = "@(#) Plotter V6.0  92/08/15  AxisCore.c";
+static char SCCSid[] = "@(#) Plotter V6.0  93/02/12  AxisCore.c";
 
 /*
 
@@ -99,7 +101,7 @@ static XtResource resources[] = {
   {
      XtNticInterval, XtCTicInterval,
      XtRDouble, sizeof(double),
-     off(tic_interval), XtRImmediate, (XtPointer) &dflt_tic
+     off(tic_interval), XtRDouble, (XtPointer) &dflt_tic
   },
   {
      XtNvertical, XtCVertical,
