@@ -2278,9 +2278,9 @@ AtPlotterWidget pw;
 XtWidgetGeometry *req, *rep;
 {
 #ifdef DEBUG
-     fprintf(stderr, "QueryGeometry: w=%d(c=%d) h=%d(c=%d) mode=%x\n",
+     fprintf(stderr, "QueryGeometry: w=%d(c=%d) h=%d(c=%d) mode=%x(%s)\n",
 	     req->width, pw->core.width, req->height, pw->core.height,
-	     req->request_mode);
+	     req->request_mode, s);
 #endif
      rep->request_mode = CWWidth | CWHeight;
      rep->width = pw->core.width < DEFAULT_WIDTH
