@@ -16,8 +16,12 @@
  *                                      ANSI C compilers quiet
  *      klin, Sat Aug 15 10:31:50 1992, patchlevel 4
  *                                      Changed <At/..> to <X11/At/..>.
+ *      klin, Fri Dec 11 15:55:12 1992, patchlevel 5
+ *                                      Bug in setting tic interval fixed.
+ *                                      Calculate number of subtics dependent
+ *                                      on length in pixels between the tics.
  */
-static char SCCSid[] = "@(#) Plotter V6.0  92/08/15  XYAxis.c";
+static char SCCSid[] = "@(#) Plotter V6.0  92/12/11  XYAxis.c";
 
 /*
 
@@ -220,7 +224,7 @@ AtXYAxisWidget req, new;
 	       ax->axis_transform = AtTransformLINEAR;
 	  }
 	  else {
-	       ax->tic_interval = ax->auto_tics ? ac->tic_interval : TIC_INT;
+	       ax->tic_interval = ax->auto_tics ? TIC_INT : ac->tic_interval;
 	       LogAxisInitialize(new);
 	  }
      }
@@ -234,7 +238,7 @@ AtXYAxisWidget req, new;
 	       ax->min = ac->min;
 	       ax->max = ac->max;
 	  }
-	  ax->tic_interval = ax->auto_tics ? ac->tic_interval : TIC_INT;
+	  ax->tic_interval = ax->auto_tics ? TIC_INT : ac->tic_interval;
 	  LinAxisInitialize(new);
      }
 }
@@ -426,22 +430,25 @@ double min, max;
      /*
       * Now figure out subtics.
       * If it makes sense to do 5 or 10 subdivision, do it.
-      * Otherwise do a power of 2
+      * Otherwise do a power of 2.
+      * Respect the length in pixels between tics.
       */
+     if(ac->num_tics > 1)
+	  len = len / (ac->num_tics - 1);
      if (mult == 2) {
-	  if (nst >= 8)      nst = 7;
-	  else if (nst >= 4) nst = 3;
-	  else if (nst >= 2) nst = 1;
-	  else               nst = 0;
+	  if      (nst >= 8  && len > 56) nst = 7;
+	  else if (nst >= 4  && len > 24) nst = 3;
+	  else if (nst >= 2  && len >  6) nst = 1;
+	  else                            nst = 0;
      }
      else {    /* 1 or 5 */
-	  if (nst >= 10)     nst = 9;
-	  else if (nst >= 5) nst = 4;
-	  else if (nst >= 2) nst = 1;
-	  else               nst = 0;
+	  if      (nst >= 10 && len > 72) nst = 9;
+	  else if (nst >= 5  && len > 32) nst = 4;
+	  else if (nst >= 2  && len >  8) nst = 1;
+	  else                            nst = 0;
      }
-
      ax->subtics_per_tic = nst;
+
      return ret;
 }
 
