@@ -1,4 +1,4 @@
-/* Copyright 1990,91 GROUPE BULL -- See license conditions in file COPYRIGHT */
+/* Copyright 1990-92 GROUPE BULL -- See license conditions in file COPYRIGHT */
 /*****************************************************************************\
 * XpmCrDataFI.c:                                                              *
 *                                                                             *
@@ -12,38 +12,36 @@
 #ifdef VMS
 #include "sys$library:string.h"
 #else
-#ifdef SYSV
+#if defined(SYSV) || defined(SVR4)
 #include <string.h>
 #else
 #include <strings.h>
 #endif
 #endif
 
-LFUNC(CreateData, int, (char ***data_return,
-		    xpmInternAttrib * attrib, XpmAttributes * attributes));
-
 LFUNC(CreateTransparentColor, int, (char **dataptr, unsigned int *data_size,
 				    char **colors, unsigned int cpp,
 				    unsigned int mask_pixel,
 				    char ***colorTable));
 
-LFUNC(CreateOtherColors, int, (FILE *file, char **colors, XColor *xcolors,
-			      unsigned int ncolors, unsigned int cpp,
-			      unsigned int mask_pixel, char ***colorTable,
-			      unsigned int ncolors2, Pixel *pixels,
-			      char *rgb_fname));
+LFUNC(CreateOtherColors, int, (char **dataptr, unsigned int *data_size,
+			       char **colors, XColor *xcolors,
+			       unsigned int ncolors, unsigned int cpp,
+			       unsigned int mask_pixel, char ***colorTable,
+			       unsigned int ncolors2, Pixel *pixels,
+			       char *rgb_fname));
 
-LFUNC(CreatePixels, int, (char **dataptr, unsigned int width,
-			  unsigned int height, unsigned int cpp,
-			  unsigned int *pixels, char **colors));
+LFUNC(CreatePixels, void, (char **dataptr, unsigned int width,
+			   unsigned int height, unsigned int cpp,
+			   unsigned int *pixels, char **colors));
 
-LFUNC(CountExtensions, int, (XpmExtension *ext, unsigned int num,
-			     unsigned int *ext_size,
-			     unsigned int *ext_nlines));
+LFUNC(CountExtensions, void, (XpmExtension *ext, unsigned int num,
+			      unsigned int *ext_size,
+			      unsigned int *ext_nlines));
 
-LFUNC(CreateExtensions, int, (char **dataptr, unsigned int offset,
-			      XpmExtension *ext, unsigned int num,
-			      unsigned int ext_nlines));
+LFUNC(CreateExtensions, void, (char **dataptr, unsigned int offset,
+			       XpmExtension *ext, unsigned int num,
+			       unsigned int ext_nlines));
 
 int
 XpmCreateDataFromImage(display, data_return, image, shapeimage, attributes)
@@ -71,7 +69,7 @@ XpmCreateDataFromImage(display, data_return, image, shapeimage, attributes)
 			       attributes, &attrib);
 
     if (ErrorStatus == XpmSuccess)
-	ErrorStatus = CreateData(data_return, &attrib, attributes);
+	ErrorStatus = xpmCreateData(data_return, &attrib, attributes);
 
     xpmFreeInternAttrib(&attrib);
 
@@ -84,13 +82,13 @@ XpmCreateDataFromImage(display, data_return, image, shapeimage, attributes)
   { if (header) { \
         for (l = 0; l < header_nlines; l++) \
 	    if (header[l]) \
-		free(header[l]); \
-	free(header); \
+		XpmFree(header[l]); \
+	XpmFree(header); \
     } \
     return(status); }
 
-static int
-CreateData(data_return, attrib, attributes)
+int
+xpmCreateData(data_return, attrib, attributes)
     char ***data_return;
     xpmInternAttrib *attrib;
     XpmAttributes *attributes;
@@ -121,7 +119,7 @@ CreateData(data_return, attrib, attributes)
      */
     header_nlines = 1 + attrib->ncolors;
     header_size = sizeof(char *) * header_nlines;
-    header = (char **) calloc(header_size, sizeof(char *));
+    header = (char **) XpmCalloc(header_size, sizeof(char *));
     if (!header)
 	RETURN(XpmNoMemory);
 
@@ -142,7 +140,7 @@ CreateData(data_return, attrib, attributes)
 	sprintf(s, " XPMEXT");
 
     l = strlen(buf) + 1;
-    *header = (char *) malloc(l);
+    *header = (char *) XpmMalloc(l);
     if (!*header)
 	RETURN(XpmNoMemory);
     header_size += l;
@@ -170,7 +168,7 @@ CreateData(data_return, attrib, attributes)
     ErrorStatus =
 	CreateOtherColors(header + 1 + offset, &header_size,
 			  attrib->colorStrings + offset,
-			  attrib->xcolors + offset, attrib->ncolors,
+			  attrib->xcolors + offset, attrib->ncolors - offset,
 			  attrib->cpp, (infos ? attributes->mask_pixel : 0),
 			  (infos ? attributes->colorTable : NULL),
 			  (infos ? attributes->ncolors : 0),
@@ -188,7 +186,7 @@ CreateData(data_return, attrib, attributes)
     data_size = header_size + (attrib->height + ext_nlines) * sizeof(char *)
 	+ attrib->height * offset + ext_size;
 
-    data = (char **) malloc(data_size);
+    data = (char **) XpmMalloc(data_size);
     if (!data)
 	RETURN(XpmNoMemory);
 
@@ -250,7 +248,7 @@ char ***colorTable;
 	sprintf(s, "\tc %s", TRANSPARENT_COLOR);
 
     l = strlen(buf) + 1;
-    s = (char *) malloc(l);
+    s = (char *) XpmMalloc(l);
     if (!s)
 	return(XpmNoMemory);
     *data_size += l;
@@ -323,7 +321,7 @@ char *rgb_fname;
 	    s += strlen(s);
 	}
 	l = strlen(buf) + 1;
-	s = (char *) malloc(l);
+	s = (char *) XpmMalloc(l);
 	if (!s)
 	    return(XpmNoMemory);
 	*data_size += l;
@@ -334,7 +332,7 @@ char *rgb_fname;
     return(XpmSuccess);
 }
 
-static int
+static void
 CreatePixels(dataptr, width, height, cpp, pixels, colors)
 char **dataptr;
 unsigned int width;
@@ -348,25 +346,20 @@ char **colors;
 
     h = height - 1;
     offset = width * cpp + 1;
-    for (y = 0; y < h; y++, dataptr++) {
+    for (y = 0; /* test is inside loop */ ; y++, dataptr++) {
 	s = *dataptr;
 	for (x = 0; x < width; x++, pixels++) {
 	    strncpy(s, colors[*pixels], cpp);
 	    s += cpp;
 	}
 	*s = '\0';
+	if (y >= h)
+	    break;		/* LEAVE LOOP */
 	*(dataptr + 1) = *dataptr + offset;
     }
-    /* duplicate some code to avoid a test in the loop */
-    s = *dataptr;
-    for (x = 0; x < width; x++, pixels++) {
-	strncpy(s, colors[*pixels], cpp);
-	s += cpp;
-    }
-    *s = '\0';
 }
 
-static int
+static void
 CountExtensions(ext, num, ext_size, ext_nlines)
 XpmExtension *ext;
 unsigned int num;
@@ -391,7 +384,7 @@ unsigned int *ext_nlines;
     *ext_nlines = nlines;
 }
 
-static int
+static void
 CreateExtensions(dataptr, offset, ext, num, ext_nlines)
 char **dataptr;
 unsigned int offset;
