@@ -18,7 +18,7 @@ xpmDataType xpmDataTypes[] =
 #ifdef VMS
  NULL
 #else
- NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL
+ NULL, NULL, NULL, 0, 0, NULL, NULL, NULL, NULL
 #endif
 };
 
@@ -45,6 +45,8 @@ XpmReadFileToImage(display, filename, image_return,
     if (shapeimage_return)
 	*shapeimage_return = NULL;
 
+    xpmInitAttributes(attributes);
+
     if ((ErrorStatus = xpmReadFile(filename, &mdata)) != XpmSuccess)
 	return (ErrorStatus);
 
