@@ -30,11 +30,11 @@ XpmReadFileToPixmap(display, d, filename, pixmap_return,
      * initialize return values 
      */
     if (pixmap_return) {
-	*pixmap_return = NULL;
+	*pixmap_return = 0;
 	imageptr = &image;
     }
     if (shapemask_return) {
-	*shapemask_return = NULL;
+	*shapemask_return = 0;
 	shapeimageptr = &shapeimage;
     }
 
@@ -63,7 +63,7 @@ XpmReadFileToPixmap(display, d, filename, pixmap_return,
 	 * XDestroyImage free the image data but mnemosyne don't know about it
 	 * so I free them by hand to avoid mnemalyse report it as lost data.
 	 */
-	free(image->data);
+	XpmFree(image->data);
 #endif
 	XDestroyImage(image);
 	XFreeGC(display, gc);
@@ -83,7 +83,7 @@ XpmReadFileToPixmap(display, d, filename, pixmap_return,
 	 * XDestroyImage free the image data but mnemosyne don't know about it
 	 * so I free them by hand to avoid mnemalyse report it as lost data.
 	 */
-	free(shapeimage->data);
+	XpmFree(shapeimage->data);
 #endif
 	XDestroyImage(shapeimage);
 	XFreeGC(display, gc);
