@@ -1,4 +1,4 @@
-/* Copyright 1990,91 GROUPE BULL -- See license conditions in file COPYRIGHT */
+/* Copyright 1990-92 GROUPE BULL -- See license conditions in file COPYRIGHT */
 /*****************************************************************************\
 * XpmWrFFrI.c:                                                                *
 *                                                                             *
@@ -12,48 +12,31 @@
 #ifdef VMS
 #include "sys$library:string.h"
 #else
-#ifdef SYSV
+#if defined(SYSV) || defined(SVR4)
 #include <string.h>
+#define index strchr
+#define rindex strrchr
 #else
 #include <strings.h>
 #endif
 #endif
 
-LFUNC(WriteData, int, (xpmData * mdata,
-		    xpmInternAttrib * attrib, XpmAttributes * attributes));
+LFUNC(WriteTransparentColor, void, (FILE *file, char **colors,
+				    unsigned int cpp, unsigned int mask_pixel,
+				    char ***colorTable));
 
-LFUNC(WriteTransparentColor, int, (FILE *file, char **colors, unsigned int cpp,
-				   unsigned int mask_pixel,
-				   char ***colorTable));
+LFUNC(WriteOtherColors, void, (FILE *file, char **colors, XColor *xcolors,
+			       unsigned int ncolors, unsigned int cpp,
+			       unsigned int mask_pixel, char ***colorTable,
+			       unsigned int ncolors2, Pixel *pixels,
+			       char *rgb_fname));
 
-LFUNC(WriteOtherColors, int, (FILE *file, char **colors, XColor *xcolors,
-			      unsigned int ncolors, unsigned int cpp,
-			      unsigned int mask_pixel, char ***colorTable,
-			      unsigned int ncolors2, Pixel *pixels,
-			      char *rgb_fname));
-
-LFUNC(WritePixels, int, (File *file, unsigned int width, unsigned int height,
+LFUNC(WritePixels, int, (FILE *file, unsigned int width, unsigned int height,
 			 unsigned int cpp, unsigned int *pixels,
 			 char **colors));
 
-LFUNC(WriteExtensions, int, (File *file, XpmExtension *ext, unsigned int num));
-
-#ifdef NEED_STRDUP
-LFUNC(strdup, char *, (char *s1));
-
-static char *
-strdup (s1)
-    char *s1;
-{
-    char *s2;
-    int l = strlen(s1) + 1;
-    if (s2 = (char *) malloc(l))
-	strncpy(s2, s1, l);
-    return s2;
-}
-
-#endif
-
+LFUNC(WriteExtensions, void, (FILE *file, XpmExtension *ext,
+			      unsigned int num));
 
 int
 XpmWriteFileFromImage(display, filename, image, shapeimage, attributes)
@@ -107,19 +90,19 @@ XpmWriteFileFromImage(display, filename, image, shapeimage, attributes)
 
     if (ErrorStatus == XpmSuccess) {
 	attrib.name = name;
-	ErrorStatus = WriteData(&mdata, &attrib, attributes);
+	ErrorStatus = xpmWriteData(&mdata, &attrib, attributes);
     }
     xpmFreeInternAttrib(&attrib);
     XpmDataClose(&mdata);
     if (new_name)
-	free(name);
+	XpmFree(name);
 
     return (ErrorStatus);
 }
 
 
-static int
-WriteData(mdata, attrib, attributes)
+int
+xpmWriteData(mdata, attrib, attributes)
     xpmData *mdata;
     xpmInternAttrib *attrib;
     XpmAttributes *attributes;
@@ -206,7 +189,7 @@ WriteData(mdata, attrib, attributes)
     return (XpmSuccess);
 }
 
-static int
+static void
 WriteTransparentColor(file, colors, cpp, mask_pixel, colorTable)
 FILE *file;
 char **colors;
@@ -232,7 +215,7 @@ char ***colorTable;
     fprintf(file, "\",\n");
 }
 
-static int
+static void
 WriteOtherColors(file, colors, xcolors, ncolors, cpp, mask_pixel, colorTable,
 		 ncolors2, pixels, rgb_fname)
 FILE *file;
@@ -310,7 +293,7 @@ char **colors;
     unsigned int x, y, h;
 
     h = height - 1;
-    p = buf = (char *) malloc(width * cpp + 2);
+    p = buf = (char *) XpmMalloc(width * cpp + 3);
     *buf = '"';
     if (!buf)
 	return(XpmNoMemory);
@@ -335,11 +318,11 @@ char **colors;
     *s = '\0';
     fprintf(file, "%s", buf);
 
-    free(buf);
+    XpmFree(buf);
     return(XpmSuccess);
 }
 
-static int
+static void
 WriteExtensions(file, ext, num)
 FILE *file;
 XpmExtension *ext;
