@@ -142,7 +142,7 @@ SetColor(display, colormap, colorname, color_index,
 	    else
 	      ncols = 1 << DefaultDepth(display, DefaultScreen(display));
 
-	    cols = (XColor*)calloc(ncols,sizeof(XColor));
+	    cols = (XColor*)XpmCalloc(ncols,sizeof(XColor));
 	    for (i = 0; i < ncols; ++i) cols[i].pixel = i;
 	    XQueryColors(display,colormap,cols,ncols);
 
@@ -171,10 +171,10 @@ SetColor(display, colormap, colorname, color_index,
 		(long)cols[closepix].blue  >= (long)xcolor.blue  - closeness &&
 		(long)cols[closepix].blue  <= (long)xcolor.blue  + closeness)
 	    {
-	      xcolor = cols[closepix]; free(cols);
+	      xcolor = cols[closepix]; XpmFree(cols);
 	      if (!XAllocColor(display, colormap, &xcolor)) return (1);
 	    }
-	    else { free(cols); return (1); }
+	    else { XpmFree(cols); return (1); }
 	  }
 	  else return (1);
 	}
@@ -315,20 +315,20 @@ CreateColors(display, attributes, ct, ncolors,
 #undef RETURN
 #ifdef Debug
 /*
- * XDestroyImage free the image data but mnemosyne don't know about it
- * so I free them by hand to avoid mnemalyse report it as lost data.
+ * XDestroyImage XpmFree the image data but mnemosyne don't know about it
+ * so I XpmFree them by hand to avoid mnemalyse report it as lost data.
  */
 #define RETURN(status) \
     { if (image) { \
-	free(image->data); \
+	XpmFree(image->data); \
 	XDestroyImage(image); } \
     if (shapeimage) { \
-	free(shapeimage->data); \
+	XpmFree(shapeimage->data); \
 	XDestroyImage(shapeimage); } \
-    if (image_pixels) free(image_pixels); \
-    if (mask_pixels) free(mask_pixels); \
+    if (image_pixels) XpmFree(image_pixels); \
+    if (mask_pixels) XpmFree(mask_pixels); \
     if (npixels) XFreeColors(display, colormap, pixels, npixels, 0); \
-    if (pixels) free(pixels); \
+    if (pixels) XpmFree(pixels); \
     return (status); }
 
 #else
@@ -336,10 +336,10 @@ CreateColors(display, attributes, ct, ncolors,
 #define RETURN(status) \
     { if (image) XDestroyImage(image); \
     if (shapeimage) XDestroyImage(shapeimage); \
-    if (image_pixels) free(image_pixels); \
-    if (mask_pixels) free(mask_pixels); \
+    if (image_pixels) XpmFree(image_pixels); \
+    if (mask_pixels) XpmFree(mask_pixels); \
     if (npixels) XFreeColors(display, colormap, pixels, npixels, 0); \
-    if (pixels) free(pixels); \
+    if (pixels) XpmFree(pixels); \
     return (status); }
 
 #endif
@@ -392,18 +392,18 @@ xpmCreateImage(display, attrib, image_return, shapeimage_return, attributes)
      * malloc pixels index tables 
      */
 
-    image_pixels = (Pixel *) malloc(sizeof(Pixel) * attrib->ncolors);
+    image_pixels = (Pixel *) XpmMalloc(sizeof(Pixel) * attrib->ncolors);
     if (!image_pixels)
 	return(XpmNoMemory);
 
-    mask_pixels = (Pixel *) malloc(sizeof(Pixel) * attrib->ncolors);
+    mask_pixels = (Pixel *) XpmMalloc(sizeof(Pixel) * attrib->ncolors);
     if (!mask_pixels)
 	RETURN(ErrorStatus);
 
     mask_pixel = UNDEF_PIXEL;
 
     /* maximum of allocated pixels will be the number of colors */
-    pixels = (Pixel *) malloc(sizeof(Pixel) * attrib->ncolors);
+    pixels = (Pixel *) XpmMalloc(sizeof(Pixel) * attrib->ncolors);
     if (!pixels)
 	RETURN(ErrorStatus);
 
@@ -464,8 +464,8 @@ xpmCreateImage(display, attrib, image_return, shapeimage_return, attributes)
 	SetImagePixels1(shapeimage, attrib->width, attrib->height,
 			attrib->pixelindex, mask_pixels);
     }
-    free(mask_pixels);
-    free(pixels);
+    XpmFree(mask_pixels);
+    XpmFree(pixels);
 
     /*
      * if requested store used pixels in the XpmAttributes structure 
@@ -478,7 +478,7 @@ xpmCreateImage(display, attrib, image_return, shapeimage_return, attributes)
 	    unsigned int a;
 
 	    attributes->npixels = attrib->ncolors - 1;
-	    pixels = (Pixel *) malloc(sizeof(Pixel) * attributes->npixels);
+	    pixels = (Pixel *) XpmMalloc(sizeof(Pixel) * attributes->npixels);
 	    if (pixels) {
 		p1 = image_pixels;
 		p2 = pixels;
@@ -493,14 +493,14 @@ xpmCreateImage(display, attrib, image_return, shapeimage_return, attributes)
 		attributes->pixels = NULL;
 		attributes->npixels = 0;
 	    }
-	    free(image_pixels);
+	    XpmFree(image_pixels);
 	} else {
 	    attributes->pixels = image_pixels;
 	    attributes->npixels = attrib->ncolors;
 	}
 	attributes->mask_pixel = mask_pixel;
     } else
-	free(image_pixels);
+	XpmFree(image_pixels);
 
 
     /*
@@ -548,7 +548,7 @@ CreateXImage(display, visual, depth, width, height, image_return)
     /* now that bytes_per_line must have been set properly alloc data */
 
     (*image_return)->data =
-	(char *) malloc((*image_return)->bytes_per_line * height);
+	(char *) XpmMalloc((*image_return)->bytes_per_line * height);
 
     if (!(*image_return)->data) {
 	XDestroyImage(*image_return);
@@ -660,6 +660,10 @@ xpm_znormalizeimagebits(bp, img)
 
     switch (img->bits_per_pixel) {
 
+    case 2:
+        _XReverse_Bytes(bp, 1);
+        break;
+
     case 4:
 	*bp = ((*bp >> 4) & 0xF) | ((*bp << 4) & ~0xF);
 	break;
@@ -957,7 +961,7 @@ SetImagePixels1(image, width, height, pixelindex, pixels)
 		    if (pixels[*iptr] & 1)
 			data[ZINDEX1(x, y, image)] |= 1 << (x & 7);
 		    else
-			data[ZINDEX1(x, y, image)] &= ~(1 << x & 7);
+			data[ZINDEX1(x, y, image)] &= ~(1 << (x & 7));
 		}
     }
 }
