@@ -1,4 +1,4 @@
-/* Copyright 1990,91 GROUPE BULL -- See license conditions in file COPYRIGHT */
+/* Copyright 1990-92 GROUPE BULL -- See license conditions in file COPYRIGHT */
 /*****************************************************************************\
 * misc.c:                                                                     *
 *                                                                             *
@@ -13,7 +13,7 @@
 /*
  * Free the computed color table
  */
-
+void
 xpmFreeColorTable(colorTable, ncolors)
     char ***colorTable;
     int ncolors;
@@ -26,10 +26,10 @@ xpmFreeColorTable(colorTable, ncolors)
 	    if (*ct) {
 		for (b = 0, cts = *ct; b <= NKEYS; b++, cts++)
 		    if (*cts)
-			free(*cts);
-		free(*ct);
+			XpmFree(*cts);
+		XpmFree(*ct);
 	    }
-	free(colorTable);
+	XpmFree(colorTable);
     }
 }
 
@@ -38,7 +38,7 @@ xpmFreeColorTable(colorTable, ncolors)
  * Intialize the xpmInternAttrib pointers to Null to know
  * which ones must be freed later on.
  */
-
+void
 xpmInitInternAttrib(attrib)
     xpmInternAttrib *attrib;
 {
@@ -54,7 +54,7 @@ xpmInitInternAttrib(attrib)
 /*
  * Free the xpmInternAttrib pointers which have been allocated
  */
-
+void
 xpmFreeInternAttrib(attrib)
     xpmInternAttrib *attrib;
 {
@@ -64,15 +64,15 @@ xpmFreeInternAttrib(attrib)
     if (attrib->colorTable)
 	xpmFreeColorTable(attrib->colorTable, attrib->ncolors);
     if (attrib->pixelindex)
-	free(attrib->pixelindex);
+	XpmFree(attrib->pixelindex);
     if (attrib->xcolors)
-	free(attrib->xcolors);
+	XpmFree(attrib->xcolors);
     if (attrib->colorStrings) {
 	ncolors = attrib->ncolors;
 	for (a = 0, sptr = attrib->colorStrings; a < ncolors; a++, sptr++)
 	    if (*sptr)
-		free(*sptr);
-	free(attrib->colorStrings);
+		XpmFree(*sptr);
+	XpmFree(attrib->colorStrings);
     }
 }
 
@@ -80,6 +80,7 @@ xpmFreeInternAttrib(attrib)
 /*
  * Free array of extensions
  */
+void
 XpmFreeExtensions(extensions, nextensions)
     XpmExtension *extensions;
     int          nextensions;
@@ -88,16 +89,19 @@ XpmFreeExtensions(extensions, nextensions)
     XpmExtension *ext;
     char **sptr;
 
-    for (i = 0, ext = extensions; i < nextensions; i++, ext++) {
-	free(ext->name);
-	nlines = ext->nlines;
-	for (j = 0, sptr = ext->lines; j < nlines; j++, sptr++)
-	    if (*sptr)
-		free(*sptr);
-	if (ext->lines)
-	    free(ext->lines);
+    if (extensions) {
+	for (i = 0, ext = extensions; i < nextensions; i++, ext++) {
+	    if (ext->name)
+		XpmFree(ext->name);
+	    nlines = ext->nlines;
+	    for (j = 0, sptr = ext->lines; j < nlines; j++, sptr++)
+		if (*sptr)
+		    XpmFree(*sptr);
+	    if (ext->lines)
+		XpmFree(ext->lines);
+	}
+	XpmFree(extensions);
     }
-    free(extensions);
 }
 
 
@@ -110,18 +114,37 @@ XpmAttributesSize()
     return sizeof(XpmAttributes);
 }
 
+/*
+ * Init returned data to free safely later on
+ */
+void
+xpmInitAttributes(attributes)
+    XpmAttributes *attributes;
+{
+  if (attributes) {
+    attributes->pixels = NULL;
+    attributes->npixels = 0;
+    attributes->colorTable = NULL;
+    attributes->ncolors = 0;
+    attributes->hints_cmt = NULL;
+    attributes->colors_cmt = NULL;
+    attributes->pixels_cmt = NULL;
+    attributes->nextensions = 0;
+    attributes->extensions = NULL;
+  }
+}
 
 /*
  * Free the XpmAttributes structure members
  * but the structure itself
  */
-
+void
 XpmFreeAttributes(attributes)
     XpmAttributes *attributes;
 {
     if (attributes) {
 	if (attributes->valuemask & XpmReturnPixels && attributes->pixels) {
-	    free(attributes->pixels);
+	    XpmFree(attributes->pixels);
 	    attributes->pixels = NULL;
 	    attributes->npixels = 0;
 	}
@@ -132,20 +155,21 @@ XpmFreeAttributes(attributes)
 		attributes->ncolors = 0;
 	    }
 	    if (attributes->hints_cmt) {
-		free(attributes->hints_cmt);
+		XpmFree(attributes->hints_cmt);
 		attributes->hints_cmt = NULL;
 	    }
 	    if (attributes->colors_cmt) {
-		free(attributes->colors_cmt);
+		XpmFree(attributes->colors_cmt);
 		attributes->colors_cmt = NULL;
 	    }
 	    if (attributes->pixels_cmt) {
-		free(attributes->pixels_cmt);
+		XpmFree(attributes->pixels_cmt);
 		attributes->pixels_cmt = NULL;
 	    }
 	    if (attributes->pixels) {
-		free(attributes->pixels);
+		XpmFree(attributes->pixels);
 		attributes->pixels = NULL;
+		attributes->npixels = 0;
 	    }
 	}
 	if (attributes->valuemask & XpmReturnExtensions
@@ -163,7 +187,7 @@ XpmFreeAttributes(attributes)
  * Store into the XpmAttributes structure the required informations stored in
  * the xpmInternAttrib structure.
  */
-
+void
 xpmSetAttributes(attrib, attributes)
     xpmInternAttrib *attrib;
     XpmAttributes *attributes;
@@ -182,3 +206,22 @@ xpmSetAttributes(attrib, attributes)
 	attributes->valuemask |= XpmSize;
     }
 }
+
+#ifdef NEED_STRDUP
+
+/*
+ * in case strdup is not provided by the system here is one
+ * which does the trick
+ */
+char *
+strdup (s1)
+    char *s1;
+{
+    char *s2;
+    int l = strlen(s1) + 1;
+    if (s2 = (char *) XpmMalloc(l))
+	strncpy(s2, s1, l);
+    return s2;
+}
+
+#endif
