@@ -1,4 +1,4 @@
-/* Copyright 1990,91 GROUPE BULL -- See license conditions in file COPYRIGHT */
+/* Copyright 1990-92 GROUPE BULL -- See license conditions in file COPYRIGHT */
 /*****************************************************************************\
 * rgb.c:                                                                      *
 *                                                                             *
@@ -19,7 +19,7 @@
 #include "sys$library:string.h"
 #else
 #include <ctype.h>
-#ifdef SYSV
+#if defined(SYSV) || defined(SVR4)
 #include <string.h>
 #else
 #include <strings.h>
@@ -72,7 +72,7 @@ xpmReadRgbNames(rgb_fname, rgbn)
 	    continue;
 	}
 	/* Allocate memory for ascii name. If error give up here. */
-	if (!(rgbname = (char *) malloc(strlen(name) + 1)))
+	if (!(rgbname = (char *) XpmMalloc(strlen(name) + 1)))
 	    break;
 
 	/* Copy string to ascii name and lowercase it. */
@@ -132,5 +132,5 @@ int rgbn_max;
     xpmRgbName *rgb;
 
     for (i = 0, rgb = rgbn; i < rgbn_max; i++, rgb++)
-	free(rgb->name);
+	XpmFree(rgb->name);
 }
