@@ -13,7 +13,7 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Mon Jan 18 04:01:22 MET 1993 on dec1.wu-wien.ac.at
+ * Creation: Sun Feb  7 19:26:18 MET 1993 on dec1.wu-wien.ac.at
  * Author: genc
  * Version: 0.92
  */
@@ -2730,12 +2730,14 @@ char        **argv;
 
 #include <X11/Xaw/Viewport.h>
 /* 
+ * hint: R5
  * void
  * XawViewportSetCoordinates
  * 	in: Widget			# viewport Widget
  * 	in: Position			# x position
  * 	in: Position			# y position
  */
+#ifndef PRER5
 
 int 
 com_viewportSetCoordinates(clientData, comInterpreter, argc, argv)
@@ -2779,8 +2781,10 @@ char        **argv;
      DBUG_RETURN (TCL_OK);
      }     
 
+#endif
 
 /* 
+ * hint: R5
  * void
  * XawViewportSetLocation
  * 	in: Widget			# viewport Widget
@@ -2788,6 +2792,7 @@ char        **argv;
  * 	in: Position			# yoffset
 
  */
+#ifndef PRER5
 
 int 
 com_viewportSetLocation(clientData, comInterpreter, argc, argv)
@@ -2831,6 +2836,7 @@ char        **argv;
      DBUG_RETURN (TCL_OK);
      }     
 
+#endif
 
 #else
 #include <string.h>
@@ -2926,8 +2932,12 @@ Initialize_XawGen()
  Tcl_CreateCommand(interpreter, "toggleSetCurrent", com_toggleSetCurrent, NULL, NULL);
  Tcl_CreateCommand(interpreter, "toggleSetRadioData", com_toggleSetRadioData, NULL, NULL);
  Tcl_CreateCommand(interpreter, "toggleUnsetCurrent", com_toggleUnsetCurrent, NULL, NULL);
+#ifndef PRER5
  Tcl_CreateCommand(interpreter, "viewportSetCoordinates", com_viewportSetCoordinates, NULL, NULL);
+#endif
+#ifndef PRER5
  Tcl_CreateCommand(interpreter, "viewportSetLocation", com_viewportSetLocation, NULL, NULL);
+#endif
 
 #else
 #endif
