@@ -13,7 +13,7 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Mon Jan 18 04:00:58 MET 1993 on dec1.wu-wien.ac.at
+ * Creation: Sat Feb 13 02:00:48 MET 1993 on dec1.wu-wien.ac.at
  * Author: genc
  * Version: 0.92
  */
@@ -60,7 +60,7 @@ freeProc      *freeFuncPtr;
 
     DBUG_PRINT("cvtToString", ("Converting to <%s>", 
 			       XrmQuarkToString(quarkOfType)));
-
+/*
     if (quarkOfType == qString)
 	{
 	*freeFuncPtr = TCL_VOLATILE;
@@ -98,7 +98,7 @@ freeProc      *freeFuncPtr;
 	sprintf(result, "%hd", (Position)(long)clientData);        	
 	return result;
 	}
-/*    
+    
     if (quarkOfType == qFloat)
 	{
 	*freeFuncPtr = XtFree;
@@ -106,8 +106,8 @@ freeProc      *freeFuncPtr;
 
 	if (sizeof(float)>sizeof(XtPointer)) {
 	fprintf(stderr,"groesser\n");
-	    sprintf(result, "%f", (*(float *)clientData));
-}
+	sprintf(result, "%f", (*(float *)clientData));
+	}
 	else 
 	  {
 	  fprintf(stderr,"kleiner,gleich %p %f\n", 
@@ -129,14 +129,14 @@ freeProc      *freeFuncPtr;
 	    sprintf(result, "%f", clientData);
 	return result;
 	}
-*/
+
     if (quarkOfType == qBoolean)
 	{
 	*freeFuncPtr = TCL_STATIC;
 	return (Boolean)(int)clientData ? "true" : "false";   
 	}
     
-
+*/
         /* last ressort: if nothing helps, try "real" converter */
 
         {
@@ -181,6 +181,80 @@ freeProc     *freeFuncPtr;
 	return NULL;
 	}
 
+    if (Qtype == qString)
+	{
+	String    valueString;
+	*freeFuncPtr = TCL_VOLATILE;
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valueString, NULL);
+	return valueString;
+	}
+
+    /* this is the Default value for the following types 
+     * assuming that dense code is better than one instruction more
+     */ 
+    *freeFuncPtr = XtFree;
+	
+    if (Qtype == qInt) 
+	{
+	int valueInt;
+	result = XtMalloc(INT_AS_STRING);
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valueInt, NULL);
+	sprintf(result, "%d", (int)valueInt);
+	return result;
+	}
+
+    if (Qtype == qPosition) 
+	{
+	Position    valuePosition;
+	result = XtMalloc(INT_AS_STRING);
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valuePosition, NULL);
+	sprintf(result, "%h", valuePosition);
+	return result;
+        }
+
+    if (Qtype == qDimension) 
+	{
+	Dimension    valueDimension;
+	result = XtMalloc(INT_AS_STRING);
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valueDimension, NULL);
+	sprintf(result, "%hu", valueDimension);
+	return result;
+        }
+
+    if (Qtype == qCardinal)
+	{
+	Cardinal    valueCardinal;
+	result = XtMalloc(INT_AS_STRING);
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valueCardinal, NULL);
+	sprintf(result, "%u", valueCardinal);	
+	return result;
+	}
+
+    if (Qtype == qBoolean)
+	{
+	Boolean    valueBoolean;
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valueBoolean, NULL);
+	return valueBoolean ? "true" : "false";   
+	}
+
+
+    if (Qtype == qFloat) 
+	{
+	float    valueFloat;
+	result = XtMalloc(FLOAT_AS_STRING);
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valueFloat, NULL);
+	sprintf(result, "%f", valueFloat);
+	return result;
+	}
+
+    if (Qtype == qDouble) 
+	{
+	double    valueDouble;
+	result = XtMalloc(FLOAT_AS_STRING);
+	XtVaGetValues(w, XrmQuarkToString(Qname), &valueDouble, NULL);
+	sprintf(result, "%f", valueDouble);
+	return result;
+	}
 
      /* Callbacks sind ... anders: die String-Information 
 	       kommt aus wafe's privatem Memory-Management und nicht 
@@ -204,32 +278,15 @@ freeProc     *freeFuncPtr;
 		}
 	    ptr = ptr->next;
 	    }
+	return result;
 	}
-    else
-    if (Qtype == qFloat) 
-	{
-	float    valueFloat;
-	*freeFuncPtr = XtFree;
-	result = XtMalloc(FLOAT_AS_STRING);
-	XtVaGetValues(w, XrmQuarkToString(Qname), &valueFloat, NULL);
-	sprintf(result, "%f", valueFloat);
-	}
-    else
-    if (Qtype == qDouble) 
-	{
-	double    valueDouble;
-	*freeFuncPtr = XtFree;
-	result = XtMalloc(FLOAT_AS_STRING);
-	XtVaGetValues(w, XrmQuarkToString(Qname), &valueDouble, NULL);
-	sprintf(result, "%f", valueDouble);
-	}
-    else
+
     if (Qtype == qWidgetList) 
         {
-	Widget    *children, *wPtr;
-        int        numChildren;
-        int        i, length=0;
-	char   *ptr;
+	Widget  *children, *wPtr;
+        int      numChildren;
+        int      i, length=0;
+	char    *ptr;
 
         XtVaGetValues(w, XtNnumChildren, &numChildren,
                             XtNchildren,    &children,    NULL);
@@ -244,27 +301,22 @@ freeProc     *freeFuncPtr;
             strcat(result,XtName(*wPtr));
             strcat(result," ");
             }
-
-        *freeFuncPtr = XtFree;  
+	return result;
         }
+
     else 
 	{
 /*
-	XtVaGetValues(w, XrmQuarkToString(Qname), &value, NULL);
-*/
 	XtSetArg(arg, XrmQuarkToString(Qname), &value);
 	XtGetValues(w, &arg, (Cardinal)1);
 
 	if (!(result = cvtToString(value, Qtype, freeFuncPtr)))
 	    {
-	      fprintf(stderr, "Wafe(getValues): Couldn't convert value\n");
-	      *freeFuncPtr = TCL_STATIC;
-	      return NULL;
-	    }
-
-	DBUG_PRINT("cvtToString", ("returns <%s>",result)); 
+*/
+	fprintf(stderr, "Wafe(getValues): Couldn't convert value\n");
+	*freeFuncPtr = TCL_STATIC;
+	return NULL;
 	}
-    return result;
     }
 
 
