@@ -15,8 +15,8 @@
  * implied warranty.
  *
  * Date: Mon, Apr 13 1992
- * Author: Stefan Nusser
- * Version: 0.91
+ * Author: Stefan Nusser, Gustaf Neumann
+ * Version: 0.93
  */
 
 /*
@@ -25,13 +25,31 @@
  *                 This file contains the main function as well as some
  *                 utility procedures, which are used in several places:
  *
+ *          resource and name handling:
  *                 getQTypeOfAttribute
+ *                 getResOfClass
+ *                 getConOfClass
  *                 convert
  *                 name2Widget
- *                 convert
+ *                 widgetListToList
+ *                 intsToTcl
+ *
+ *          memory management:
+ *                 addToEndOfWidgetList
+ *                 deleteFromWidgetList
+ *                 MMgetAttribList
+ *                 MMreplace
+ *                 MMfreeGarbage
  *                 killCallbackProc
+ *
+ *          error and exception handling:
  *                 signalHandler
- *                 main
+ *                 IOErrorHandler
+ *                 convError
+ *                 argcError
+ *                 noVarCompError
+ *          communication:
+ *                 iSocketPair
  */
 
 
@@ -672,9 +690,17 @@ Widget        w;
 		else
 		if (output.size == sizeof(short))
 		    argPtr->value = (XtArgVal) *(short *)output.addr;
-		else
+		else 
                 if (output.size == sizeof(double))
-		    argPtr->value = (XtArgVal) (double *)output.addr; 
+		    {
+		    /* argPtr->value = (XtArgVal) (double *) output.addr;*/
+		    /* we have to copy doubles to allow multiple doubles
+		       in one widget creation or setValue command */
+		    argPtr->value = (XtArgVal)XtMalloc(sizeof(double));
+		    *(double *)(argPtr->value) = *(double *)(output.addr);
+		    MMreplace(&currentStrInfo,currentAttrib,
+			      (char *)(argPtr->value),XtFree);
+		    }
 		else 
                 if (output.size == sizeof(char))
 		    argPtr->value = (XtArgVal) *(char *)output.addr;
@@ -917,7 +943,7 @@ XErrorEvent *xe;
  *****************************************************************************/
 #ifdef PIPES
 int
-iSocketPair(fd,onlyOne)
+iSocketPair(fd, onlyOne)
 int      fd[4],onlyOne;
     {
     if (pipe(&fd[0])<0) return(-1);
@@ -1047,7 +1073,7 @@ char **env;
        * in file mode from the filename and in direct  mode it is defined to be Wafe
        */
 
-    strcpy(class, argv[0]);
+    strcpy(appClass, argv[0]);
     application[0] = '\0';
 
      /*
@@ -1108,7 +1134,7 @@ char **env;
 		    exit(-1);
 		    }
 
-                strcpy(class, "Wafe");
+                strcpy(appClass, "Wafe");
                 }
 	    else
                              /***  Direct - Mode  ***/
@@ -1120,7 +1146,7 @@ char **env;
                 fromClient = fileno(stdin);
                 errorClient = -1;
 
-                strcpy(class, "Wafe");
+                strcpy(appClass, "Wafe");
                 args++; 
 	        }
 	    else 
@@ -1135,7 +1161,7 @@ char **env;
 	    if (argv[args][2] == 'p')
 	        {
 		opt_p = True;
-                strcpy(class, argv[args+1]);
+                strcpy(appClass, argv[args+1]);
                 strcpy(application, argv[args+1]);
                 args += 2;
 	        }
@@ -1150,7 +1176,7 @@ char **env;
 
                 fileMode = True;
                 strcpy(file, argv[args+1]);   /* Next Arg = File to execute */
-                strcpy(class, file);
+                strcpy(appClass, file);
 
                 args +=2;
                 }
@@ -1185,22 +1211,22 @@ char **env;
        * If the program's name contains a path specification cut it off...
        */
     
-    if (charPtr = strrchr(class, '/'))
-	strcpy(class, ++charPtr);
+    if (charPtr = strrchr(appClass, '/'))
+	strcpy(appClass, ++charPtr);
 
    /*
      *  We will need this information when we execute the application process ...
      */
 
     if (!application[0]) 
-	strcpy(application, class); 
+	strcpy(application, appClass); 
 
      /*
        * If the name contains a dot, which is not allowed in Xt's class names, substitute it
        * with a dash (keep this in mind, it will possibly affect the name of the AD file!
        */
 
-    while(charPtr = strrchr(class, '.'))
+    while(charPtr = strrchr(appClass, '.'))
 	*charPtr = '-';
          
      /* Just because argv[0] will appear in the titlebar of the 
@@ -1209,7 +1235,7 @@ char **env;
       */
 
 
-    cargv[0] = XtNewString(class);
+    cargv[0] = XtNewString(appClass);
 
     /* 
       *  Now create class: Capitalized X, second letter capitalized, 
@@ -1217,17 +1243,17 @@ char **env;
       *  will be searched! 
       */
 
-    if ((class[0] == 'x') || (class[0] == 'X'))
+    if ((appClass[0] == 'x') || (appClass[0] == 'X'))
 	{
-	class[0] = 'X';
-	class[1] = toupper(class[1]);
+	appClass[0] = 'X';
+	appClass[1] = toupper(appClass[1]);
 	}
     else
-	class[0] = toupper(class[0]);
+	appClass[0] = toupper(appClass[0]);
 
      /* Must initialize here, so that Xt can strip off its arguments */
 
-    topLevel = XtVaAppInitialize(&appContext, class, NULL, 0, 
+    topLevel = XtVaAppInitialize(&appContext, appClass, NULL, 0, 
 				 &cargc, cargv, NULL, NULL); 
 /*
     XtAppSetErrorHandler(appContext,IOErrorHandler);
@@ -1446,8 +1472,8 @@ printf("sp %d %d %d %d\n",sp[0],sp[1],sp[2],sp[3]);
     Initialize_XcGen();
     Initialize_rddGen();
    
-/*  using non-caching converter for names to widget to avoid dangling references
- *  thanx Christian Holzbaur
+/*  using non-caching converter for names to widget to avoid 
+ *  dangling references (thanx Christian Holzbaur)
  */
     XtSetTypeConverter(XtRString, XtRWidget, 
         (XtTypeConverter)CvtStringToWidget, 
