@@ -81,7 +81,7 @@ WAFE_EXTERN char INITIALIZE(promptChar, '%');
 
 WAFE_EXTERN XrmQuark       currentAttrib;
 
-WAFE_EXTERN char           class[50];
+WAFE_EXTERN char           appClass[50];
 WAFE_EXTERN char           application[100];
 WAFE_EXTERN char           packages[100];
 
