@@ -1,4 +1,4 @@
-/* Copyright 1990,91 GROUPE BULL -- See license conditions in file COPYRIGHT */
+/* Copyright 1990-92 GROUPE BULL -- See license conditions in file COPYRIGHT */
 /*****************************************************************************\
 * sxpm.c:                                                                     *
 *                                                                             *
@@ -8,11 +8,13 @@
 \*****************************************************************************/
 
 #ifdef VMS
+#include "sys$library:stdio.h"
 #include "decw$include:Xlib.h"
 #include "decw$include:Intrinsic.h"
 #include "decw$include:Shell.h"
 #include "decw$include:shape.h"
 #else
+#include <stdio.h>
 #include <X11/StringDefs.h>
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
@@ -67,6 +69,7 @@ static char *plaid[] =
 "data2_2",
 "XPMEXT",
 "foo",
+"",
 "XPMEXT ext3",
 "data3",
 "XPMENDEXT"
@@ -91,18 +94,18 @@ typedef struct _XpmIcon {
     Pixmap pixmap;
     Pixmap mask;
     XpmAttributes attributes;
-}        XpmIcon;
+} XpmIcon;
 
 static char **command;
 static Widget topw;
 static XpmIcon view, icon;
 static XrmOptionDescRec options[] = {
-		  {"-hints", ".hints", XrmoptionNoArg, (XtPointer) "True"},
-		     {"-icon", ".icon", XrmoptionSepArg, (XtPointer) NULL},
+    {"-hints", ".hints", XrmoptionNoArg, (XtPointer) "True"},
+    {"-icon", ".icon", XrmoptionSepArg, (XtPointer) NULL},
 };
 
 main(argc, argv)
-    unsigned int argc;
+    int argc;
     char **argv;
 {
     int ErrorStatus;
@@ -270,6 +273,11 @@ main(argc, argv)
 		continue;
 	    }
 	}
+	if (strcmp(argv[n], "-closecolors") == 0) {
+	    valuemask |= XpmCloseness;
+	    view.attributes.closeness = 40000;
+	    continue;
+	}
 	if (strncmp(argv[n], "-rgb", 3) == 0) {
 	    if (n < argc - 1) {
 		valuemask |= XpmRgbFilename;
@@ -338,13 +346,25 @@ main(argc, argv)
 #endif
 
     if (input || stdinf) {
-#ifdef Debug2
-	free(data);
-#endif
 	view.attributes.valuemask |= XpmReturnInfos;
 	view.attributes.valuemask |= XpmReturnPixels;
 	view.attributes.valuemask |= XpmReturnExtensions;
 
+#ifdef Debug2
+	XpmFree(data);
+
+	ErrorStatus = XpmReadFileToData(input, &data);
+	ErrorMessage(ErrorStatus, "ReadFileToData");
+	ErrorStatus = XpmCreatePixmapFromData(dpy, win, data,
+					      &view.pixmap, &view.mask,
+					      &view.attributes);
+	ErrorMessage(ErrorStatus, "CreatePixmapFromData");
+	ErrorStatus = XpmWriteFileFromData("sxpmout.xpm", data);
+	ErrorMessage(ErrorStatus, "WriteFileFromData");
+	XpmFree(data);
+	XpmFreeAttributes(&view.attributes);
+#endif
+	
 	ErrorStatus = XpmReadFileToPixmap(dpy, win, input,
 					  &view.pixmap, &view.mask,
 					  &view.attributes);
@@ -364,7 +384,7 @@ main(argc, argv)
 	ErrorStatus = XpmCreatePixmapFromData(dpy, win, data,
 					      &view.pixmap, &view.mask,
 					      &view.attributes);
-	free(data);
+	XpmFree(data);
 #else
 	ErrorStatus = XpmCreatePixmapFromData(dpy, win, plaid,
 					      &view.pixmap, &view.mask,
@@ -410,7 +430,7 @@ main(argc, argv)
 
 	if (input) {
 	    xString = (char *) XtMalloc((sizeof(char) * strlen(input)) + 20);
-	    sprintf(xString, "Sxpm: %s\0", input);
+	    sprintf(xString, "Sxpm: %s", input);
 	    XStoreName(dpy, XtWindow(topw), xString);
 	    XSetIconName(dpy, XtWindow(topw), xString);
 	} else if (stdinf) {
@@ -455,6 +475,8 @@ Usage()
 	    "[-s symbol_name color_name]  Overwrite color defaults.");
     fprintf(stderr, "%s\n",
 	    "[-p symbol_name pixel_value] Overwrite color defaults.");
+    fprintf(stderr, "%s\n",
+	    "[-closecolors]               Try to use `close' colors.");
     fprintf(stderr, "%s\n",
 	    "[-plaid]                     Read the included plaid pixmap.");
     fprintf(stderr, "%s\n",
@@ -553,7 +575,7 @@ kinput(widget, tag, xe, b)
     XEvent *xe;
     Boolean *b;
 {
-    char c;
+    char c = '\0';
 
     XLookupString(&(xe->xkey), &c, 1, NULL, NULL);
     if (c == 'q' || c == 'Q')
