@@ -16,7 +16,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /user6/ouster/tcl/RCS/tclBasic.c,v 1.131 92/06/21 14:09:41 ouster Exp $ SPRITE (Berkeley)";
+static char rcsid[] = "$Header: /user6/ouster/tcl/RCS/tclBasic.c,v 1.133 92/08/21 15:45:32 ouster Exp $ SPRITE (Berkeley)";
 #endif
 
 #include "tclInt.h"
@@ -552,7 +552,7 @@ Tcl_Eval(interp, cmd, flags, termPtr)
 	}
 	if (*src == '#') {
 	    for (src++; *src != 0; src++) {
-		if (*src == '\n') {
+		if ((*src == '\n') && (src[-1] != '\\')) {
 		    src++;
 		    break;
 		}
@@ -979,8 +979,8 @@ int
 #ifndef lint
 Tcl_VarEval(va_alist)
 #else
-Tcl_VarEval(interp, p, va_alist)
-    Tcl_Interp *interp;		/* Interpreter in which to execute command. */
+Tcl_VarEval(iPtr, p, va_alist)
+    Tcl_Interp *iPtr;		/* Interpreter in which to execute command. */
     char *p;			/* One or more strings to concatenate,
 				 * terminated with a NULL string. */
 #endif
