@@ -13,21 +13,13 @@
 
 #ifdef VMS
 #include "decw$include:Xlib.h"
-#include "decw$include:Intrinsic.h"
-#include "sys$library:stdio.h"
 #else
 #include <X11/Xlib.h>
-#include <X11/Intrinsic.h>
-#include <stdio.h>
 #endif
 
-/* we keep the same codes as for Bitmap management */
-#ifndef _XUTIL_H_
-#ifdef VMS
-#include "decw$include:Xutil.h"
-#else
-#include <X11/Xutil.h>
-#endif
+/* let's define Pixel if it is not done yet */
+#ifndef _XtIntrinsic_h
+typedef unsigned long	Pixel;	    /* Index into colormap		*/
 #endif
 
 /* Return ErrorStatus codes:
@@ -140,59 +132,60 @@ typedef struct {
 extern "C" {
 #endif
 
-    FUNC(XpmCreatePixmapFromData, int, (Display * display,
+    FUNC(XpmCreatePixmapFromData, int, (Display *display,
 					Drawable d,
 					char **data,
-					Pixmap * pixmap_return,
-					Pixmap * shapemask_return,
-					XpmAttributes * attributes));
+					Pixmap *pixmap_return,
+					Pixmap *shapemask_return,
+					XpmAttributes *attributes));
 
-    FUNC(XpmCreateDataFromPixmap, int, (Display * display,
+    FUNC(XpmCreateDataFromPixmap, int, (Display *display,
 					char ***data_return,
 					Pixmap pixmap,
 					Pixmap shapemask,
-					XpmAttributes * attributes));
+					XpmAttributes *attributes));
 
-    FUNC(XpmReadFileToPixmap, int, (Display * display,
+    FUNC(XpmReadFileToPixmap, int, (Display *display,
 				    Drawable d,
 				    char *filename,
-				    Pixmap * pixmap_return,
-				    Pixmap * shapemask_return,
-				    XpmAttributes * attributes));
+				    Pixmap *pixmap_return,
+				    Pixmap *shapemask_return,
+				    XpmAttributes *attributes));
 
-    FUNC(XpmWriteFileFromPixmap, int, (Display * display,
+    FUNC(XpmWriteFileFromPixmap, int, (Display *display,
 				       char *filename,
 				       Pixmap pixmap,
 				       Pixmap shapemask,
-				       XpmAttributes * attributes));
+				       XpmAttributes *attributes));
 
-    FUNC(XpmCreateImageFromData, int, (Display * display,
+    FUNC(XpmCreateImageFromData, int, (Display *display,
 				       char **data,
-				       XImage ** image_return,
-				       XImage ** shapemask_return,
-				       XpmAttributes * attributes));
+				       XImage **image_return,
+				       XImage **shapemask_return,
+				       XpmAttributes *attributes));
 
-    FUNC(XpmCreateDataFromImage, int, (Display * display,
+    FUNC(XpmCreateDataFromImage, int, (Display *display,
 				       char ***data_return,
-				       XImage * image,
-				       XImage * shapeimage,
-				       XpmAttributes * attributes));
+				       XImage *image,
+				       XImage *shapeimage,
+				       XpmAttributes *attributes));
 
-    FUNC(XpmReadFileToImage, int, (Display * display,
+    FUNC(XpmReadFileToImage, int, (Display *display,
 				   char *filename,
-				   XImage ** image_return,
-				   XImage ** shapeimage_return,
-				   XpmAttributes * attributes));
+				   XImage **image_return,
+				   XImage **shapeimage_return,
+				   XpmAttributes *attributes));
 
-    FUNC(XpmWriteFileFromImage, int, (Display * display,
+    FUNC(XpmWriteFileFromImage, int, (Display *display,
 				      char *filename,
-				      XImage * image,
-				      XImage * shapeimage,
-				      XpmAttributes * attributes));
+				      XImage *image,
+				      XImage *shapeimage,
+				      XpmAttributes *attributes));
 
+    FUNC(XpmReadFileToData, int, (char *filename, char  ***data_return));
     FUNC(XpmAttributesSize, int, ());
-    FUNC(XpmFreeAttributes, int, (XpmAttributes * attributes));
-    FUNC(XpmFreeExtensions, int, (XpmExtension * extensions, int nextensions));
+    FUNC(XpmFreeAttributes, void, (XpmAttributes *attributes));
+    FUNC(XpmFreeExtensions, void, (XpmExtension *extensions, int nextensions));
 
 #ifdef __cplusplus
 }					/* for C++ V2.0 */
